@@ -13,11 +13,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-# Python 3.4+ comes with mock in unittest
-try:
-    from unittest import mock
-except ImportError:
-    import mock
+from unittest import mock
 from unittest import TestCase
 from datetime import datetime
 from dateutil.tz import tzutc
@@ -93,13 +89,13 @@ class TestProbeRepresentation(TestCase):
         with mock.patch('ripe.atlas.cousteau.request.AtlasRequest.get') as request_mock:
             request_mock.return_value = True, {}
             Probe(id=1, fields=["probes"])
-            self.assertEquals(request_mock.call_args[1], {"fields": "probes"})
+            self.assertEqual(request_mock.call_args[1], {"fields": "probes"})
             Probe(id=1, fields=["probes", "data"])
-            self.assertEquals(request_mock.call_args[1], {"fields": "probes,data"})
+            self.assertEqual(request_mock.call_args[1], {"fields": "probes,data"})
             Probe(id=1, fields="probes,data")
-            self.assertEquals(request_mock.call_args[1], {"fields": "probes,data"})
+            self.assertEqual(request_mock.call_args[1], {"fields": "probes,data"})
             Probe(id=1, fields=1)
-            self.assertEquals(request_mock.call_args[1], {})
+            self.assertEqual(request_mock.call_args[1], {})
 
 
 class TestMeasurementRepresentation(TestCase):
@@ -191,13 +187,13 @@ class TestMeasurementRepresentation(TestCase):
         with mock.patch('ripe.atlas.cousteau.request.AtlasRequest.get') as request_mock:
             request_mock.return_value = True, {}
             Measurement(id=1, fields=["probes"])
-            self.assertEquals(request_mock.call_args[1], {"fields": "probes"})
+            self.assertEqual(request_mock.call_args[1], {"fields": "probes"})
             Measurement(id=1, fields=["probes", "data"])
-            self.assertEquals(request_mock.call_args[1], {"fields": "probes,data"})
+            self.assertEqual(request_mock.call_args[1], {"fields": "probes,data"})
             Measurement(id=1, fields="probes,data")
-            self.assertEquals(request_mock.call_args[1], {"fields": "probes,data"})
+            self.assertEqual(request_mock.call_args[1], {"fields": "probes,data"})
             Measurement(id=1, fields=1)
-            self.assertEquals(request_mock.call_args[1], {})
+            self.assertEqual(request_mock.call_args[1], {})
 
     def test_populate_times(self):
         with mock.patch('ripe.atlas.cousteau.request.AtlasRequest.get') as request_mock:
